@@ -68,7 +68,6 @@ my $ref       = '';
 my $mpirun    = 'mpirun';
 my $parse_cmd = '';
 my $gmx_cmd   = "gmx";
-my $mdrun_cmd = "";
 my %progs = ( 'grompp'   => '',
               'mdrun'    => '',
               'pdb2gmx'  => '',
@@ -179,9 +178,6 @@ sub setup_vars()
     foreach my $prog ( keys %progs ) {
         $progs{$prog} = "$gmx_cmd$suffix $prog";
     }
-    if ( "$mdrun_cmd" ne "" ) {
-        $progs{"mdrun"} = $mdrun_cmd;
-    }
     $ref = 'reference_' . ($double > 0 ? 'd' : 's');
 
     # now do -tight or -relaxed stuff
@@ -1474,7 +1470,7 @@ sub run_single_ed_system {
   }
 
   # Make the .tpr file
-  $nerror += do_system("$progs{'grompp'} -f $input_dir/grompp.mdp -c $input_dir/conf -r $input_dir/conf -p $input_dir/topol -maxwarn 1 >$grompp_out 2>$grompp_err");
+  $nerror += do_system("$progs{'grompp'} -f $input_dir/grompp.mdp -c $input_dir/conf -r $input_dir/conf -p $input_dir/topol -maxwarn 2 >$grompp_out 2>$grompp_err");
 
   if ($ediArgs) {
       # Make the essential dynamics .edi input file
@@ -1682,7 +1678,6 @@ sub usage {
 Usage: ./gmxtest.pl [ -np N ] [ -nt 1 ] [ -npme n ]
                     [ -verbose ] [ -double ] [ -bluegene ]
                     [ -suffix xxx ] [ -reprod ] [ -mpirun mpirun_command ]
-                    [ -mdrun mdrun_command ]
                     [ -crosscompile ] [ -relaxed ] [ -tight ] [ -mdparam xxx ]
                     [ -keep ]
                     [ $dirs | all ]
@@ -1838,12 +1833,6 @@ for ($kk=0; ($kk <= $#ARGV); $kk++) {
 	    $mpirun = $ARGV[$kk];
 	}
     }
-    elsif ($arg eq '-mdrun' ) {
-	if ($kk <$#ARGV) {
-	    $kk++;
-	    $mdrun_cmd = $ARGV[$kk];
-	}
-    }
     elsif ($arg eq '-mdparam' ) {
 	# The user is responsible for providing sensible values for
 	# this flag when they want them
